@@ -5,10 +5,10 @@ from cool.views.exceptions import CoolAPIException, CoolPermissionAPIException
 from cool.views.response import ResponseData
 from cool.views.serializer import BaseSerializer
 from cool.views.sites import ViewSite
-from cool.views.utils import get_api_doc, get_api_info
+from cool.views.utils import get_api_doc, get_api_doc_html, get_api_info
 from cool.views.view import CoolBFFAPIView, PageMixin
 
 __all__ = [
     'ErrorCode', 'CoolAPIException', 'CoolPermissionAPIException', 'ResponseData', 'BaseSerializer', 'ViewSite',
-    'get_api_doc', 'get_api_info', 'CoolBFFAPIView', 'PageMixin',
+    'get_api_doc', 'get_api_doc_html', 'get_api_info', 'CoolBFFAPIView', 'PageMixin',
 ]
